@@ -51,6 +51,8 @@ def folder_ls(folder='.'):
 def print_work_directory():
 	print(os.getcwd())
 
+clear = lambda: os.system('clear')
+
 class User(object):
 	def __init__(self, address=None, password=None):
 		self.address = address
@@ -78,7 +80,7 @@ class Mailshell():
 			"sch": self.display_sc,
 			"ls": folder_ls,
 			"pwd": print_work_directory,
-			"clear": lambda: os.system('clear'),
+			"clear": clear,
 			"help": helper.shell_commands,
 			"version": helper.get_version,
 			"exit": sys.exit
@@ -246,6 +248,7 @@ class Mailshell():
 			for att in attachments: content += '\x1b[33m    ' + att.get_filename() + '\x1b[0m' + '\n'
 		content += '-' * len(MESSAGE_STR)
 		print(content)
+		print("type 'send' to send your message.")
 
 	def check_mail_box(self):
 		if not self.user:
@@ -314,6 +317,7 @@ def shell_line(user):
 
 def run():
 	# Startup
+	clear()
 	dispaly_logo()
 	print(f"\x1b[4mWelcome {getuser()}\x1b[0m")
 	print("type 'help' to see your available commands.\n")
